@@ -1,7 +1,7 @@
 __author__ = "SutandoTsukai181"
 __copyright__ = "Copyright 2021, SutandoTsukai181"
 __license__ = "MIT"
-__version__ = "1.4.0"
+__version__ = "1.4.2"
 
 import struct
 from contextlib import contextmanager
@@ -117,9 +117,22 @@ class BinaryReader:
 
         self.extend([0] * size)
 
+    def align_pos(self, size: int) -> int:
+        """Aligns the current position to the given size.\n
+        Advances the current position by (size - (current_position % size)), but only if it is not aligned.\n
+        Returns the number of bytes skipped.
+        """
+        skipped = 0
+
+        if self.pos() % size:
+            skipped = size - (self.pos() % size)
+            self.seek(skipped, Whence.CUR)
+
+        return skipped
+
     def align(self, size: int) -> int:
         """Aligns the buffer to the given size.\n
-        Extends the buffer from its end by (size - (buffer_size % size)).\n
+        Extends the buffer from its end by (size - (buffer_size % size)), but only if it is not aligned.\n
         Will advance the buffer position only if the position was at the end of the buffer.\n
         Returns the number of bytes padded.
         """
@@ -222,18 +235,18 @@ class BinaryReader:
         self.__idx = new_offset
         return struct.unpack_from(end + str(count) + format, self.__buf, i)
 
-    def read_bytes(self, length=1) -> bytes:
-        """Reads a bytes object with the given length from the current position."""
-        return self.__read_type("s", length)[0]
+    def read_bytes(self, size=1) -> bytes:
+        """Reads a bytes object with the given size from the current position."""
+        return self.__read_type("s", size)[0]
 
-    def read_str(self, length=0, encoding=None) -> str:
-        """Reads a string with the given length from the current position.\n
-        If length is `0` (default), will read until the first null byte (which the position will be set after).\n
+    def read_str(self, size=None, encoding=None) -> str:
+        """Reads a string with the given size from the current position.\n
+        If size is not given, will read until the first null byte (which the position will be set after).\n
         If encoding is `None` (default), will use the BinaryReader's encoding.
         """
         encode = self.__encoding if encoding is None else encoding
 
-        if length == 0:
+        if size is None:
             string = bytearray()
             while self.__idx < len(self.__buf):
                 string.append(self.__buf[self.__idx])
@@ -243,108 +256,115 @@ class BinaryReader:
 
             return string.split(b'\x00', 1)[0].decode(encode)
 
-        return self.read_bytes(length).split(b'\x00', 1)[0].decode(encode)
+        if size < 0:
+            raise ValueError('size cannot be negative')
 
-    def read_int64(self, count=1) -> Union[int, Tuple[int]]:
+        return self.read_bytes(size).split(b'\x00', 1)[0].decode(encode)
+
+    def read_int64(self, count=None) -> Union[int, Tuple[int]]:
         """Reads a signed 64-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("q", count)
         return self.__read_type("q")[0]
 
-    def read_uint64(self, count=1) -> Union[int, Tuple[int]]:
+    def read_uint64(self, count=None) -> Union[int, Tuple[int]]:
         """Reads an unsigned 64-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("Q", count)
         return self.__read_type("Q")[0]
 
-    def read_int32(self, count=1) -> Union[int, Tuple[int]]:
+    def read_int32(self, count=None) -> Union[int, Tuple[int]]:
         """Reads a signed 32-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("i", count)
         return self.__read_type("i")[0]
 
-    def read_uint32(self, count=1) -> Union[int, Tuple[int]]:
+    def read_uint32(self, count=None) -> Union[int, Tuple[int]]:
         """Reads an unsigned 32-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("I", count)
         return self.__read_type("I")[0]
 
-    def read_int16(self, count=1) -> Union[int, Tuple[int]]:
+    def read_int16(self, count=None) -> Union[int, Tuple[int]]:
         """Reads a signed 16-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("h", count)
         return self.__read_type("h")[0]
 
-    def read_uint16(self, count=1) -> Union[int, Tuple[int]]:
+    def read_uint16(self, count=None) -> Union[int, Tuple[int]]:
         """Reads an unsigned 16-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("H", count)
         return self.__read_type("H")[0]
 
-    def read_int8(self, count=1) -> Union[int, Tuple[int]]:
+    def read_int8(self, count=None) -> Union[int, Tuple[int]]:
         """Reads a signed 8-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("b", count)
         return self.__read_type("b")[0]
 
-    def read_uint8(self, count=1) -> Union[int, Tuple[int]]:
+    def read_uint8(self, count=None) -> Union[int, Tuple[int]]:
         """Reads an unsigned 8-bit integer.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("B", count)
         return self.__read_type("B")[0]
 
-    def read_float(self, count=1) -> Union[float, Tuple[float]]:
+    def read_float(self, count=None) -> Union[float, Tuple[float]]:
         """Reads a 32-bit float.\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("f", count)
         return self.__read_type("f")[0]
 
-    def read_half_float(self, count=1) -> Union[float, Tuple[float]]:
+    def read_half_float(self, count=None) -> Union[float, Tuple[float]]:
         """Reads a 16-bit float (half-float).\n
-        If count is greater than 1, will return a tuple of values instead of 1 value.
+        If count is given, will return a tuple of values instead of 1 value.
         """
-        if count > 1:
+        if count is not None:
             return self.__read_type("e", count)
         return self.__read_type("e")[0]
 
-    def read_struct(self, cls: type, count=1, *args) -> BrStruct:
+    def read_struct(self, cls: type, count=None, *args) -> BrStruct:
         """Creates and returns an instance of the given `cls` after calling its `__br_read__` method.\n
         `cls` must be a subclass of BrStruct.\n
-        If count is not equal to 1, will return a tuple of values instead of 1 value.\n
+        If count is given, will return a tuple of values instead of 1 value.\n
         Additional arguments given after `count` will be passed to the `__br_read__` method of `cls`.\n
         """
         if not (cls and issubclass(cls, BrStruct)):
             raise Exception(
                 f'BinaryReader Error: {cls} is not a subclass of BrStruct.')
 
-        result = []
-        for _ in range(count):
-            br_struct = cls()
-            br_struct.__br_read__(self, *args)
-            result.append(br_struct)
+        if count is not None:
+            result = []
 
-        if count == 1:
-            return result[0]
+            for _ in range(count):
+                br_struct = cls()
+                br_struct.__br_read__(self, *args)
+                result.append(br_struct)
 
-        return tuple(result)
+            return tuple(result)
+
+        br_struct = cls()
+        br_struct.__br_read__(self, *args)
+
+        return br_struct
 
     def __write_type(self, format: str, value, is_iterable: bool) -> None:
         i = self.__idx
@@ -380,6 +400,21 @@ class BinaryReader:
         self.write_bytes(bytes_obj)
         return len(bytes_obj)
 
+    def write_str_fixed(self, string: str, size: int, encoding=None) -> None:
+        """Writes a whole string with the given size to the buffer.\n
+        If the string's size after being encoded is less than size, the remaining size will be filled with null bytes.\n
+        If it's more than size, the encoded bytes will be trimmed to size.\n
+        If encoding is `None` (default), will use the BinaryReader's encoding.
+        """
+
+        if size < 0:
+            raise ValueError('size cannot be negative')
+
+        bytes_obj = string.encode(
+            self.__encoding if encoding is None else encoding)[:size] + (b'\x00' * max(0, size - len(string)))
+        self.write_bytes(bytes_obj)
+        return len(bytes_obj)
+
     def write_int64(self, value: int) -> None:
         """Writes a signed 64-bit integer.\n
         If value is iterable, will write all of the elements in the given iterable.
